/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <contacts.h>
#include "contacts_app.h"
#include "data/data_group_create.h"
#include "data/data_common.h"

/**
 *@brief Creates new group in contacts database with provided name.
 *@param[in] group_name Group name.
 *@return This function returns 'true' if the function succeeds,
 * otherwise 'false' is returned.
 */
bool data_group_create_create(const char *group_name)
{
	int id = 0;
	bool ret = false;
	contacts_record_h rec_h = NULL;

	if (!data_common_create_record(_contacts_group._uri, &rec_h))
		return false;

	if (data_common_set_str(rec_h, _contacts_group.name, group_name))
		ret = data_common_insert_record(rec_h, &id);

	contacts_record_destroy(rec_h, true);

	return ret;
}

/**
 * @brief Checks if the group with certain name already exists.
 * @param[in] group_name The name of the group to be validated.
 * @param[out] exists If the given group name already exists,
 * then the argument is set to 'true', otherwise to 'false'.
 * @return This function returns 'true' if the function succeeds,
 * otherwise 'false' is returned.
 */
bool data_group_create_exists(const char *group_name, bool *exists)
{
	bool ret;
	int count = 0;
	contacts_list_h list_h;

	*exists = false;

	list_h = data_common_get_str_records(_contacts_group._uri, _contacts_group.name, group_name);
	if (!list_h)
		return false;

	ret = data_common_get_list_count(list_h, &count);
	contacts_list_destroy(list_h, true);

	*exists = (count > 0);

	return ret;
}
